@@ -12,7 +12,12 @@ import aws_cdk.aws_ec2._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-elasticloadbalancing", "1.48.0", __name__[0:-6], "aws-elasticloadbalancing@1.48.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-elasticloadbalancing",
+    "1.50.0",
+    __name__[0:-6],
+    "aws-elasticloadbalancing@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
